@@ -78,7 +78,7 @@ class TrivyScan(ToolGateway):
         except Exception as e:
             logger.error(f"Error during image scan of {image_name}: {e}")
 
-    def run_tool_container_sca(self, remoteconfig, token, image_name, result_file):
+    def run_tool_container_sca(self, remoteconfig, secret_tool, token_engine_container, image_name, result_file):
         trivy_version = remoteconfig["TRIVY"]["TRIVY_VERSION"]
         os_platform = platform.system()
         arch_platform = platform.architecture()[0]
